@@ -1465,8 +1465,10 @@ def compare_models( model_filenames, img, n_classes=3, identifier=None, noise_sd
             dimgup=inference( dimg, srmdl, segmentation = seglow, verbose=verbose )
             dimgupseg = dimgup['super_resolution_segmentation']
             dimgup = dimgup['super_resolution']
-            segblock = ants.resample_image_to_target( seghigh, dimgup, interp_type='nearestNeighbor'  )
+            segblock = ants.resample_image_to_target( seghigh, dimgupseg, interp_type='nearestNeighbor'  )
             segimgnn = ants.resample_image_to_target( seglow, dimgupseg, interp_type='nearestNeighbor' )
+            segblock[ dimgupseg == 0 ] = 0
+            segimgnn[ dimgupseg == 0 ] = 0
             dicenn = ants.label_overlap_measures(segblock, segimgnn)['MeanOverlap'][0]
             dicesr = ants.label_overlap_measures(segblock, dimgupseg)['MeanOverlap'][0]
         else:
